summaryrefslogtreecommitdiffstats
path: root/kpf/src/Server.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpf/src/Server.h')
-rw-r--r--kpf/src/Server.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kpf/src/Server.h b/kpf/src/Server.h
index 2e332801..97d75ed1 100644
--- a/kpf/src/Server.h
+++ b/kpf/src/Server.h
@@ -37,7 +37,7 @@ namespace KPF
/**
* Converses with a remote client. Handles requests and generates responses.
* Bandwidth is controlled by tqparent (WebServer).
*/
class Server : public TQObject
{
@@ -61,14 +61,14 @@ namespace KPF
*
* @param socket The system's socket device, used for communication.
*
* @param tqparent A WebServer, which will manage this Server.
*/
Server
(
const TQString & dir,
bool followSymlinks,
int socket,
- WebServer * tqparent
+ WebServer * parent
);
/**
@@ -37,7 +37,7 @@ namespace KPF
/**
* Converses with a remote client. Handles requests and generates responses.
- * Bandwidth is controlled by tqparent (WebServer).
+ * Bandwidth is controlled by parent (WebServer).
*/
class Server : public TQObject
@@ -61,14 +61,14 @@ namespace KPF
* @param socket The system's socket device, used for communication.
*
- * @param tqparent A WebServer, which will manage this Server.
+ * @param parent A WebServer, which will manage this Server.
*/
Server